@@ -17,7 +17,7 @@ using namespace apolloron;
 
 const char *INKF_PROGNAME = "inkf";
 const char *INKF_BRIEF    = "Yet Another Network Kanji Filter";
-const char *INKF_VERSION  = "2.0.7";
+const char *INKF_VERSION  = "2.1.0";
 const char *INKF_COPY     = "Copyright (C) 2002-2019 Masashi Astro Tachibana";
 const char *INKF_DEF_OUT  = "inkf.out";
 
@@ -982,7 +982,8 @@ void show_help() {
       "  *supported encoding is as follows:\n"
       "   ISO-2022-JP\n"
       "   Shift_JIS (CP932)\n"
-      "   EUC-JP\n"
+      "   EUC-JP (EUCJP-WIN,CP51932)\n"
+      "   EUCJP-MS\n"
       "   ISO-8859-[1,2,3,4,5,6,7,8,9,10,13,14,15,16]\n"
       "   KOI8-[R,U]\n"
       "   CP1251\n"
