@@ -48,6 +48,7 @@ extern const char *STR_UTF32BE;
 extern const char *STR_SJIS;
 extern const char *STR_JIS;
 extern const char *STR_EUCJP;
+extern const char *STR_EUCJPMS;
 extern const char *STR_ASCII;
 extern const char *STR_AUTOJP;
 extern const char *STR_EUCKR;
@@ -65,19 +66,28 @@ char* utf8_to_utf16(const char *str, long *length, char en='L');
 char* utf16_to_utf8(const char *str, long length, char en='L');
 char* utf8_to_utf32(const char *str, long *length, char en='L');
 char* utf32_to_utf8(const char *str, long length, char en='L');
-char* utf8_to_eucjp(const char* str);
-char* sjis_to_eucjp(const char* str);
-char* jis_to_eucjp(const char* str);
-char* eucjp_to_sjis(const char* str);
-char* eucjp_to_jis(const char* str);
-char* eucjp_to_utf8(const char* str);
+char* utf8_to_eucjpms(const char *str);
+char* utf8_to_eucjpwin(const char* str);
+char* sjis_to_eucjpms(const char* str);
+char* sjis_to_eucjpwin(const char* str);
+char* jis_to_eucjpms(const char* str);
+char* jis_to_eucjpwin(const char* str);
+char* eucjpms_to_sjis(const char* str);
+char* eucjpwin_to_sjis(const char* str);
+char* eucjpms_to_jis(const char* str);
+char* eucjpwin_to_jis(const char* str);
+char* eucjpms_to_utf8(const char *str);
+char* eucjpwin_to_utf8(const char* str);
+char* eucjpms_to_eucjpwin(const char *str);
+char* eucjpwin_to_eucjpms(const char *str);
 char* utf8_to_sjis(const char* str);
 char* utf8_to_jis(const char* str);
 char* sjis_to_utf8(const char* str);
 char* jis_to_utf8(const char* str);
 char* sjis_to_jis(const char* str);
 char* jis_to_sjis(const char* str);
-char* autojp_to_eucjp(const char* str);
+char* autojp_to_eucjpms(const char *str);
+char* autojp_to_eucjpwin(const char* str);
 char* autojp_to_sjis(const char* str);
 char* autojp_to_jis(const char* str);
 char* autojp_to_utf8(const char* str);
