@@ -623,7 +623,7 @@ bool JSONValue::operator !=(const JSONValue &other) const {
     return !(*this == other);
 }
 
-const char * JSONValue::asCString() const {
+const char * JSONValue::c_str() const {
     JSON_ASSERT(type_ == stringValue);
     return value_.string_;
 }
@@ -1211,6 +1211,12 @@ bool JSONValue::isObject() const {
 }
 
 
+void JSONValue::setComment(const String &comment,
+                           CommentPlacement placement) {
+    setComment(comment.c_str(), placement);
+}
+
+
 void JSONValue::setComment(const char *comment,
                            CommentPlacement placement) {
     if(!comments_)
@@ -1229,7 +1235,7 @@ bool JSONValue::hasComment(CommentPlacement placement) const {
     return comments_ != 0  &&  comments_[placement].comment_ != 0;
 }
 
-std::string JSONValue::getComment(CommentPlacement placement) const {
+String JSONValue::getComment(CommentPlacement placement) const {
     if(hasComment(placement))
         return comments_[placement].comment_;
     return "";
@@ -1378,6 +1384,12 @@ PathArgument::PathArgument(JSONValue::UInt index)
 }
 
 
+PathArgument::PathArgument(const String &key)
+    : key_(key.c_str())
+    , kind_(kindKey) {
+}
+
+
 PathArgument::PathArgument(const char *key)
     : key_(key)
     , kind_(kindKey) {
@@ -1392,6 +1404,22 @@ PathArgument::PathArgument(const std::string &key)
 // class Path
 // //////////////////////////////////////////////////////////////////
 
+Path::Path(const String &path,
+           const PathArgument &a1,
+           const PathArgument &a2,
+           const PathArgument &a3,
+           const PathArgument &a4,
+           const PathArgument &a5) {
+    InArgs in;
+    in.push_back(&a1);
+    in.push_back(&a2);
+    in.push_back(&a3);
+    in.push_back(&a4);
+    in.push_back(&a5);
+    makePath(path.c_str(), in);
+}
+
+
 Path::Path(const std::string &path,
            const PathArgument &a1,
            const PathArgument &a2,
@@ -1408,6 +1436,22 @@ Path::Path(const std::string &path,
 }
 
 
+Path::Path(const char *path,
+           const PathArgument &a1,
+           const PathArgument &a2,
+           const PathArgument &a3,
+           const PathArgument &a4,
+           const PathArgument &a5) {
+    InArgs in;
+    in.push_back(&a1);
+    in.push_back(&a2);
+    in.push_back(&a3);
+    in.push_back(&a4);
+    in.push_back(&a5);
+    makePath(path, in);
+}
+
+
 void Path::makePath(const std::string &path,
                     const InArgs &in) {
     const char *current = path.c_str();
