@@ -144,7 +144,7 @@ int test1() {
     str_a = "You get married";                         // Set String
     str_b = 100 * 10000;                               // Set String By Number
     str_c = str_a + " and have " + str_b + " kids.";   // Set String Combination
-    str_d.sprintf("%s %s", str_b.c_str(), "kids");     // Set Format String
+    str_d.sprintf("%S %s", &str_b, "kids");            // Set Format String
 #if __MD5 == 1
     str_e = str_c.crypt();
 #endif
